build_web_compilers library

Classes

Dart2JsArchiveExtractor
DartPlatform
A supported "platform" for compilation of Dart libraries.
DevCompilerBuilder
A builder which can output ddc modules!
Module
A collection of Dart libraries in a strongly connected component of the import graph.
ModuleBuilder
Creates .module files for any .dart file that is the primary dart source of a Module.
WebEntrypointBuilder
The deprecated keys for the options config for the WebEntrypointBuilder. A builder which compiles entrypoints for the web.

Enums

WebCompiler
Which compiler to use when compiling web entrypoints.

Constants

ddcBootstrapExtension → const String

Properties

dart2jsPlatform DartPlatform
final
dart2wasmPlatform DartPlatform
final
ddcPlatform DartPlatform
final
fullKernelExtension String
final
jsModuleErrorsExtension String
final
jsModuleExtension String
final
jsSourceMapExtension String
final
metadataExtension String
final
scratchSpace → ScratchSpace
A shared ScratchSpace for ddc and analyzer workers that persists throughout builds.
final
scratchSpaceResource → Resource<ScratchSpace>
A shared Resource for a ScratchSpace, which cleans up the contents of the ScratchSpace in dispose, but doesn't delete it entirely.
final
symbolsExtension String
final

Functions

initializePlatforms([bool useAdditionalUiLibraries = false]) → void
Registers the platforms with DartPlatform.
moduleExtension(DartPlatform platform) String
The extension for serialized module assets.

Exceptions / Errors

MissingModulesException
An Exception that is thrown when there are some missing modules.
UnsupportedModules
An Exception that is thrown when there are some unsupported modules.