ModuleBuilder class

Creates .module files for any .dart file that is the primary dart source of a Module.

Constructors

ModuleBuilder(DartPlatform _platform, {bool usesWebHotReload = false})

Properties

buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usesWebHotReload bool
If set, this builder will consume raw meta modules (instead of clean).
final

Methods

build(BuildStep buildStep) Future
Generates the outputs for a given BuildStep.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited